@@ -7,7 +7,7 @@ setMethod("move2ade",
             })
 
 setMethod("move2ade", 
-          signature=".MoveTrack", 
+          signature=".MoveTrackStack", 
           definition=function(x){ 
             SpatialPointsDataFrame(coords=coordinates(x), 
                                    data=data.frame(rep(rownames(x@idData), apply(data.frame(rownames(x@idData)), MARGIN=1, function(z) sum(z==as.character(x@trackId)))) )) 
@@ -38,7 +38,7 @@ setAs("ltraj", "Move", function(from) {
     if(!attr(from,"typeII"))
 	    stop('Can only work on typeII objects')
     spdf<-adehabitatLT::ltraj2spdf(from)
-    new("Move",data=(attr(from[[1]],'infolocs')), spdf, sensor=rep(factor("unknown"), nrow(spdf)), timestamps=spdf$date, idData=data.frame(row.names=paste0(attr(from[[1]], 'id'),'_', attr(from[[1]],'id')),burst=attr(from[[1]],'burst'), id=attr(from[[1]],'id')))
+    new("Move",data=(attr(from[[1]],'infolocs')), spdf, sensor=rep(factor("unknown"), nrow(spdf)), timestamps=spdf$date, idData=data.frame(row.names=paste0(attr(from[[1]], 'id'),'_', attr(from[[1]],'id')),burst=attr(from[[1]],'burst'), id=attr(from[[1]],'id')), sensorUnUsedRecords=factor(levels='unknown'))
 
 
 })
