@@ -23,9 +23,9 @@ setGeneric("speed", function(x){standardGeneric("speed")})
 setMethod("speed", 
           signature=".MoveTrackSingle",
           definition=function(x){
-            if(length(seglength(x)>0)){
-              Speed <- (seglength(x)*1000)/time.lag(x, units="secs") #meter per sec
-              return(Speed)} else {return(NA)}
+            #if(length(seglength(x)>0)){
+              Speed <- (distance(x))/time.lag(x, units="secs") #meter per sec
+              return(Speed)#} else {return(NA)}
           })
 
 setMethod("speed", 
